<?php
/**
 * Fitness Trainer functions and definitions
 *
 * @package Fitness Trainer
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'fitness_trainer_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function fitness_trainer_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Fitness Trainer, use a find and replace
	 * to change 'fitness-trainer' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'fitness-trainer', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'fitness-trainer' ),
		'footer' => __( 'Footer Menu', 'fitness-trainer' ),
	) );

	// Enable support for Post Formats.
	//add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
	
	//Enable Featured images
	add_theme_support( 'post-thumbnails' );
	
	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'fitness_trainer_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array( 'comment-list', 'search-form', 'comment-form', ) );
}
endif; // fitness_trainer_setup
add_action( 'after_setup_theme', 'fitness_trainer_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function fitness_trainer_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'fitness-trainer' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	
}
add_action( 'widgets_init', 'fitness_trainer_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function fitness_trainer_scripts() {
	
	wp_enqueue_style( 'google-font', "https://fonts.googleapis.com/css?family=Open+Sans|Dosis:400,800" );
	wp_enqueue_style( 'twitterbootstrap-min',  get_template_directory_uri()."/assets/css/bootstrap.min.css" );
	
	wp_enqueue_style( 'fitness-trainer-style', get_stylesheet_uri() );
	
	
	wp_enqueue_script( 'fitness-trainer-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	
	wp_enqueue_script( 'fitness-trainer-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array( 'jquery' ), '', true );
	
	wp_enqueue_script( 'superfish', get_template_directory_uri() . '/assets/js/superfish.js', array( 'jquery' ), '', true );
	
		
	wp_enqueue_script( 'fitness-trainer-theme-js', get_template_directory_uri() . '/assets/js/theme.js', array(), '', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'fitness_trainer_scripts' );

function fitness_trainer_add_editor_styles() {
    add_editor_style( 'assets/css/custom-editor-style.css' );
}
add_action( 'init', 'fitness_trainer_add_editor_styles' );




/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
